/*globals define*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/videodialog-test',
    'testsuite/sinon',
    'jquery',
    'ep/ui/videodialog',

    '$ready!'
], function (QUnit, fixture, sinon, $, video) {

    QUnit.module("ep/ui/videodialog", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.test('ep/ui/videodialog - check existence of videodialog methods', 8, function () {
        $.each([
            '_create',
            '_youtube',
            '_vimeo',
            '_createDialog',
            '_stopVideo',
            'open',
            'close',
            'destroy'
        ], function () {
            QUnit.ok(
                $.isFunction($.ui.uiVideodialog.prototype[this]),
                this + ' is a method of the videodialog widget'
            );
        });
    });

    QUnit.asyncTest("ep/ui/videodialog - UI tests for youtube video", function () {
        var $img = $('#youtube-wrapper .ep-helpcenter-video-list-image'),
            stopVideoSpy,
            iframeSrc;

        // instantiate videodialog widget
        $img.uiVideodialog({
          type: {
            name: 'youtube',
            url: $img.data('videourl'),
            id: $img.data('videoid'),
            ext: $img.data('videoext')
          }
        });

        // wait until widget is instantiated
        window.setTimeout(function() {
            QUnit.equal(
                !!$img.uiVideodialog('instance'),
                true,
                'uiVideodialog widget instance exists.'
            );

            // trigger click to open dialog
            $img.trigger('click');
            // wait until dialog is open
            window.setTimeout(function() {
                QUnit.equal(
                    $img.data('uiUiVideodialog').dialog.length,
                    1,
                    'Dialog was created.'
                );
                QUnit.equal(
                    $('.ui-dialog').length,
                    1,
                    'Dialog element is present in DOM.'
                );
                QUnit.equal(
                    $img.data('uiUiVideodialog').dialog.is(':visible'),
                    true,
                    'Dialog is visible.'
                );

                // register spy to investigate hide method
                stopVideoSpy = sinon.spy($img.data('uiUiVideodialog'), '_stopVideo');
                // save iframe source to test if resetted correctly in videoStop method
                iframeSrc = $img.data('uiUiVideodialog').dialog.find('iframe').attr('src');

                // use public method to close dialog
                $img.uiVideodialog('close');
                // wait until dialog is closed
                window.setTimeout(function() {
                    QUnit.equal(
                        $img.data('uiUiVideodialog').dialog.is(':visible'),
                        false,
                        'Dialog is closed.'
                    );
                    QUnit.ok(
                        stopVideoSpy.callCount === 1,
                        'Stop video method was called once.'
                    );
                    QUnit.ok(
                        $img.data('uiUiVideodialog').dialog.find('iframe').attr('src') === iframeSrc,
                        'Stop method resetted the video source correctly.'
                    );

                    // destroy widget
                    $img.uiVideodialog('destroy');
                    // wait until widget is destroyed
                    window.setTimeout(function() {
                        QUnit.equal(
                            $img.data('uiUiVideodialog') === undefined,
                            true,
                            'Widget was destroyed.'
                        );
                        QUnit.equal(
                            $('.ui-dialog').length,
                            0,
                            'Dialog element was removed from DOM.'
                        );

                        QUnit.start();
                    }, 500);
                }, 500);
            }, 500);
        }, 500);
    });

    QUnit.asyncTest("ep/ui/videodialog - UI tests for vimeo video", function () {
        var $img = $('#vimeo-wrapper .ep-helpcenter-video-list-image'),
            stopVideoSpy,
            iframeSrc;

        // instantiate videodialog widget
        $img.uiVideodialog({
          type: {
            name: 'vimeo',
            id: $img.data('videoid'),
            video: $img.data('video')
          }
        });

        // wait until widget is instantiated
        window.setTimeout(function() {
            QUnit.equal(
                !!$img.uiVideodialog('instance'),
                true,
                'uiVideodialog widget instance exists.'
            );


            // trigger click to open dialog
            $img.trigger('click');
            // wait until dialog is open
            window.setTimeout(function() {
                QUnit.equal(
                    $img.data('uiUiVideodialog').dialog.length,
                    1,
                    'Dialog was created.'
                );

                QUnit.equal(
                    $('.ui-dialog').length,
                    1,
                    'Dialog element is present in DOM.'
                );
                QUnit.equal(
                    $img.data('uiUiVideodialog').dialog.is(':visible'),
                    true,
                    'Dialog is visible.'
                );

                // register spy to investigate hide method
                stopVideoSpy = sinon.spy($img.data('uiUiVideodialog'), '_stopVideo');
                // save iframe source to test if resetted correctly in videoStop method
                iframeSrc = $img.data('uiUiVideodialog').dialog.find('iframe').attr('src');

                // use public method to close dialog
                $img.uiVideodialog('close');
                // wait until dialog is closed
                window.setTimeout(function() {
                    QUnit.equal(
                        $img.data('uiUiVideodialog').dialog.is(':visible'),
                        false,
                        'Dialog is closed.'
                    );
                    QUnit.ok(
                        stopVideoSpy.callCount === 1,
                        'Stop video method was called once.'
                    );
                    QUnit.ok(
                        $img.data('uiUiVideodialog').dialog.find('iframe').attr('src') === iframeSrc,
                        'Stop method resetted the video source correctly.'
                    );

                    // destroy widget
                    $img.uiVideodialog('destroy');
                    // wait until widget is destroyed
                    window.setTimeout(function() {
                        QUnit.equal(
                            $img.data('uiUiVideodialog') === undefined,
                            true,
                            'Widget was destroyed.'
                        );
                        QUnit.equal(
                            $('.ui-dialog').length,
                            0,
                            'Dialog element was removed from DOM.'
                        );

                        QUnit.start();
                    }, 500);
                }, 500);
            }, 500);
        }, 500);
    });
});