/*globals define*/

define([
    'testsuite/qunit',
    'jquery',
    'ep/alert',

    'testsuite/simulate',
    '$ready!'
], function (QUnit, $, ep) {
    'use strict';

    var dialog,
        expected = {
            ok: 1,
            cancel: 3,
            close: 4
        },
        result = {
            ok: 0,
            cancel: 0,
            close: 0
        };

    QUnit.module("ep/alert", {
        setup: function () {

            dialog = ep.alert({
                title: 'TestTitle',
                content: 'Test',
                ok: function (event) {
                    result.ok += 1;

                    QUnit.ok(
                        true,
                        "*Ok* runs defined action"
                    );
                },
                cancel: function () {
                    result.cancel += 1;

                    QUnit.ok(
                        true,
                        "*Cancel* runs defined action"
                    );
                },
                close: function () {
                    result.close += 1;

                    QUnit.ok(
                        true,
                        "*Close* runs defined action"
                    );
                },
                type: 'Warning'
            });

            dialog.uiDialog('open');
        },

        teardown: function () {
            dialog.uiDialog('destroy');
        }
    });



    QUnit.test("DOM structure", function () {

        // dialog exists
        QUnit.equal(
            $('body > div.ui-dialog').length,
            1,
            "$('body > div.ui-dialog').length"
        );

        // Existing dialog is an (ep) .uiDialog
        QUnit.equal(
            $('.epDialog').length,
            1,
            "is ep dialog"
        );
    });


    // each of the following test runs two functions, the actual one and *Close*
    QUnit.test("Ok button", 2, function () {
        // Button ok (triggers close and ok)
        $('.ui-dialog-buttonset button:eq(0)').simulate("click");
    });

    QUnit.test("Cancel button", 2, function () {
        // Button cancel (triggers close and cancel)
        $('.ui-dialog-buttonset button:eq(1)').simulate("click");
    });

    QUnit.test("Close button", 2, function () {
        // Button close (triggers close and cancel)
        $('.ui-dialog-titlebar-close').simulate("click");
    });

    QUnit.test("ESC Key", 2, function () {
        // Press ESC (triggers close and cancel)
        $(dialog)
            .simulate("keydown", {
                keyCode: $.ui.keyCode.ESCAPE
            })
            .simulate("keypress", {
                keyCode: $.ui.keyCode.ESCAPE
            })
            .simulate("keyup", {
                keyCode: $.ui.keyCode.ESCAPE
            });
    });

    QUnit.test('Check number and type of run acions', function () {
        QUnit.deepEqual(
            result,
            expected,
            "NUmber of fired events (ok, cancel, close) is correct"
        );
    });

});