/*jslint browser: true*/
/*global define*/

define('testsuite/qunit-fixture', ['jquery', './qunit'], function ($, QUnit) {
    'use strict';

    var updateFixture = function (html) {
            var $elm;

            // Try to use QUnit fixture element
            $elm = $('#qunit-fixture');

            // Use body if QUnit fixture element is not available
            if (!$elm.length) {
                $elm = $('body');
            }

            // Clear element and set new html content
            $elm.empty()
                .html(html);
        };

    // Register RequireJS loader for QUnit html fixtures
    return {
        normalize: function (name, normalize) {
            return normalize(name, '', true).replace(/(\.html)$/, '');
        },

        load: function (name, req, load) {
            var moduleObject = {
                    // Set loaded fixture as property
                    html: '',

                    // Initialize the fixture
                    init: function () {
                        updateFixture(moduleObject.html);
                    },

                    // Reset the fixture
                    destroy: function () {
                        updateFixture(QUnit.config.fixture);
                    }
                },

                registerHtml = function (data) {
                    moduleObject.html = data || '';

                    load(moduleObject);
                };

            if (name) {
                $.ajax({
                    // Full url
                    url: req.toUrl(name + '.html'),
                    // Cache request in browser
                    cache: false,
                    // Load as JSON
                    dataType: 'text'
                }).done(registerHtml);
            } else {
                registerHtml();
            }
        }
    };
});